==> requests-cache-0.6.1.tar.gz: requests-cache-0.6.1/CONTRIBUTORS.md <==
# Contributors
Thanks to the following people for contributing patches and suggestions:

* [Aaron-mf1](https://github.com/aaron-mf1)
* [Alex Morega](https://github.com/mgax)
* [Alex Sinitsin](https://github.com/meowcoder)
* [Andrew Kittredge](https://github.com/andrewkittredge)
* [Antonio Lima](https://github.com/themiurgo)
* [Boris Danilovich](https://github.com/borisdan)
* [Chris de Graaf](https://github.com/christopher-dG)
* [Craig](https://github.com/craigls)
* [Daniel Rech](https://github.com/dmr)
* [Dragon Dave McKee](https://github.com/scraperdragon)
* [Edward Betts](https://github.com/EdwardBetts)
* [Elan Ruusamäe](https://github.com/glensc)
* [FemtoTrader](https://github.com/femtotrader)
* [Florian Demmer](https://github.com/fdemmer)
* [GDR](https://github.com/gjedeer)
* [Garrett Reynolds](https://github.com/Garrett-R)
* [Guangnan Cheng](https://github.com/chengguangnan)
* [Honza Javorek](https://github.com/honzajavorek)
* [Ilya](https://github.com/libbkmz)
* [J Rob Gant ](https://github.com/rgant)
* [Jace Browning](https://github.com/jacebrowning)
* [Jessy Williams ](https://github.com/jkwill87)
* [John Vandenberg](https://github.com/jayvdb)
* [Jürgen Hermann](https://github.com/jhermann)
* [Kieran W](https://github.com/FredHappyface)
* [Kristian Kvilekval](https://github.com/kgk)
* [MBarkhau](https://github.com/mbarkhau)
* [Marc Abramowitz](https://github.com/msabramo)
* [Marius Gedminas](https://github.com/mgedmin)
* [Masahiro Wada](https://github.com/ar90n)
* [Massimo Santini](https://github.com/mapio)
* [Michael Beaumont](https://github.com/michaelbeaumont)
* [Michael Herman](https://github.com/mjhea0)
* [Michał Górny](https://github.com/mgorny)
* [Michał Nowotka](https://github.com/mnowotka)
* [Nathan Cahill](https://github.com/nathancahill)
* [Nick](https://github.com/kousu)
* [Olivier Dalang](https://github.com/olivierdalang)
* [Paul Furley](https://github.com/paulfurley)
* [Philipp A.](https://github.com/flying-sheep)
* [Sebastian Höffner](https://github.com/shoeffner)
* [Simon Biewald](https://github.com/Varbin)
* [Slin Lee](https://github.com/slinlee)
* [Stavros Korokithakis](https://github.com/skorokithakis)
* [Willem de Groot](https://github.com/gwillem)
* [Wouter Vanden Hove](https://github.com/WouterVH)
* [YetAnotherNerd](https://github.com/YetAnotherNerd)
* [ごろごろうまる](https://github.com/gorogoroumaru)

==> requests-cache-0.6.4.tar.gz: requests-cache-0.6.4/CONTRIBUTORS.md <==
# Contributors
Thanks to the following individuals for providing pull requests, feedback, and other
contributions that have helped to improve requests-cache:

* [Aaron-mf1](https://github.com/aaron-mf1)
* [Alex Morega](https://github.com/mgax)
* [Alex Sinitsin](https://github.com/meowcoder)
* [Andrew Kittredge](https://github.com/andrewkittredge)
* [Antonio Lima](https://github.com/themiurgo)
* [Boris Danilovich](https://github.com/borisdan)
* [Chris de Graaf](https://github.com/christopher-dG)
* [Craig](https://github.com/craigls)
* [Daniel Rech](https://github.com/dmr)
* [Dragon Dave McKee](https://github.com/scraperdragon)
* [Edward Betts](https://github.com/EdwardBetts)
* [Elan Ruusamäe](https://github.com/glensc)
* [FemtoTrader](https://github.com/femtotrader)
* [Florian Demmer](https://github.com/fdemmer)
* [GDR](https://github.com/gjedeer)
* [Garrett Reynolds](https://github.com/Garrett-R)
* [Guangnan Cheng](https://github.com/chengguangnan)
* [Honza Javorek](https://github.com/honzajavorek)
* [Ilya](https://github.com/libbkmz)
* [J Rob Gant](https://github.com/rgant)
* [Jace Browning](https://github.com/jacebrowning)
* [Jessy Williams](https://github.com/jkwill87)
* [John Vandenberg](https://github.com/jayvdb)
* [Jürgen Hermann](https://github.com/jhermann)
* [Kieran W](https://github.com/FredHappyface)
* [Kristian Kvilekval](https://github.com/kgk)
* [M Hellmund](https://github.com/MHellmund)
* [MBarkhau](https://github.com/mbarkhau)
* [Marc Abramowitz](https://github.com/msabramo)
* [Marius Gedminas](https://github.com/mgedmin)
* [Masahiro Wada](https://github.com/ar90n)
* [Massimo Santini](https://github.com/mapio)
* [Michael Beaumont](https://github.com/michaelbeaumont)
* [Michael Herman](https://github.com/mjhea0)
* [Michał Górny](https://github.com/mgorny)
* [Michał Nowotka](https://github.com/mnowotka)
* [Nathan Cahill](https://github.com/nathancahill)
* [Nick](https://github.com/kousu)
* [Olivier Dalang](https://github.com/olivierdalang)
* [Paul Furley](https://github.com/paulfurley)
* [Philipp A.](https://github.com/flying-sheep)
* [Sebastian Höffner](https://github.com/shoeffner)
* [Shiftinv](https://github.com/shiftinv)
* [Simon Biewald](https://github.com/Varbin)
* [Slin Lee](https://github.com/slinlee)
* [Stavros Korokithakis](https://github.com/skorokithakis)
* [Willem de Groot](https://github.com/gwillem)
* [Wouter Vanden Hove](https://github.com/WouterVH)
* [YetAnotherNerd](https://github.com/YetAnotherNerd)
* [ごろごろうまる](https://github.com/gorogoroumaru)
